@@ -24,7 +24,7 @@ def _hacky_entrypoint_loader(module_name):
 
 class PkgCfg:
     """
-        Contains information about an installed package that uses robotpy-build
+    Contains information about an installed package that uses robotpy-build
     """
 
     def __init__(self, entry_point):
@@ -47,7 +47,7 @@ class PkgCfg:
 
     def get_include_dirs(self) -> Optional[List[str]]:
         """
-            Include directories provided by this module
+        Include directories provided by this module
         """
         fn = getattr(self.module, "get_include_dirs", None)
         if fn:
@@ -56,7 +56,7 @@ class PkgCfg:
 
     def get_library_dirs(self) -> Optional[List[str]]:
         """
-            Directories where libraries reside
+        Directories where libraries reside
         """
         fn = getattr(self.module, "get_library_dirs", None)
         if fn:
@@ -65,7 +65,7 @@ class PkgCfg:
 
     def get_library_dirs_rel(self) -> Optional[List[str]]:
         """
-            Directories where libraries reside, relative to package
+        Directories where libraries reside, relative to package
         """
         fn = getattr(self.module, "get_library_dirs_rel", None)
         if fn:
@@ -74,7 +74,7 @@ class PkgCfg:
 
     def get_library_names(self) -> Optional[List[str]]:
         """
-            Names of libraries provided (for linking)
+        Names of libraries provided (for linking)
         """
         fn = getattr(self.module, "get_library_names", None)
         if fn:
@@ -83,7 +83,7 @@ class PkgCfg:
 
     def get_extra_objects(self) -> Optional[List[str]]:
         """
-            Names of extra objects to link in
+        Names of extra objects to link in
         """
         fn = getattr(self.module, "get_extra_objects", None)
         if fn:
@@ -92,7 +92,7 @@ class PkgCfg:
 
     def get_library_full_names(self) -> Optional[List[str]]:
         """
-            Full names of libraries provided (needed for OSX support)
+        Full names of libraries provided (needed for OSX support)
         """
         fn = getattr(self.module, "get_library_full_names", None)
         if fn:
@@ -101,7 +101,7 @@ class PkgCfg:
 
     def get_type_casters(self, casters: Dict[str, str]) -> None:
         """
-            Type caster headers provided
+        Type caster headers provided
         """
         fn = getattr(self.module, "get_type_casters", None)
         if fn:
@@ -110,20 +110,42 @@ class PkgCfg:
 
 class PkgCfgProvider:
     """
-        Retrieves information about robotpy-build packages
+    Retrieves information about robotpy-build packages
 
-        Warning: Not to be confused with 'pkg-config'
+    Warning: Not to be confused with 'pkg-config'
     """
 
     def __init__(self):
         self.pkgs = {}
-        for entry_point in iter_entry_points(group="robotpybuild", name=None):
-            try:
-                pkg = PkgCfg(entry_point)
-            except Exception as e:
-                warnings.warn(f"Error loading entry point {entry_point.name}: {e}")
-            else:
-                self.add_pkg(pkg)
+
+    def detect_pkgs(self) -> None:
+        """
+        Detect and load packages under the robotpybuild entry point group.
+        Only loads packages that are dependencies.
+        """
+        deps_names = set().union(*[pkg.depends for pkg in self.pkgs.values()])
+        entry_points = list(iter_entry_points(group="robotpybuild", name=None))
+
+        # Only load the dependencies of the package we're building.
+        # If we load the [package being built], then the current build will fail.
+        # If we load a package that depends on the [package being built],
+        # then the [package being built] will be loaded and the current build will fail.
+        run_loop = True
+        while run_loop:
+            run_loop = False
+            for ep in entry_points:
+                if ep.name in self.pkgs:  # Prevents loading the package being built
+                    continue
+                if ep.name not in deps_names and ep.name != "robotpy-build":
+                    continue
+                try:
+                    pkg = PkgCfg(ep)
+                except Exception as e:
+                    warnings.warn(f"Error loading entry point {ep.name}: {e}")
+                else:
+                    self.add_pkg(pkg)
+                    deps_names |= set(pkg.depends)
+                    run_loop = True
 
     def add_pkg(self, pkg: PkgCfg) -> None:
         self.pkgs[pkg.name] = pkg
